@@ -55,14 +55,11 @@ func newRootCmd(version string, exit func(int)) *rootCmd {
 		Use:   "goreleaser",
 		Short: "Deliver Go binaries as fast and easily as possible",
 		Long: `GoReleaser is a release automation tool for Go projects.
-Its goal is to simplify the build, release and publish steps while providing
-variant customization options for all steps.
+Its goal is to simplify the build, release and publish steps while providing variant customization options for all steps.
 
-GoReleaser is built for CI tools, you only need to download and execute it
-in your build script. Of course, you can also install it locally if you wish.
+GoReleaser is built for CI tools, you only need to download and execute it in your build script. Of course, you can also install it locally if you wish.
 
-You can also customize your entire release process through a
-single .goreleaser.yaml file.
+You can also customize your entire release process through a single .goreleaser.yaml file.
 `,
 		Version:       version,
 		SilenceUsage:  true,
