@@ -1,6 +1,7 @@
 package git_test
 
 import (
+	"context"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/git"
@@ -10,14 +11,14 @@ import (
 
 func TestNotARepo(t *testing.T) {
 	testlib.Mktmp(t)
-	_, err := git.ExtractRepoFromConfig()
+	_, err := git.ExtractRepoFromConfig(context.Background())
 	require.EqualError(t, err, `current folder is not a git repository`)
 }
 
 func TestNoRemote(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
-	_, err := git.ExtractRepoFromConfig()
+	_, err := git.ExtractRepoFromConfig(context.Background())
 	require.EqualError(t, err, `no remote configured to list refs from`)
 }
 
@@ -25,20 +26,21 @@ func TestRepoName(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
 	testlib.GitRemoteAdd(t, "git@github.com:goreleaser/goreleaser.git")
-	repo, err := git.ExtractRepoFromConfig()
+	repo, err := git.ExtractRepoFromConfig(context.Background())
 	require.NoError(t, err)
 	require.Equal(t, "goreleaser/goreleaser", repo.String())
 }
 
 func TestRepoNameWithDifferentRemote(t *testing.T) {
+	ctx := context.Background()
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
 	testlib.GitRemoteAddWithName(t, "upstream", "https://github.com/goreleaser/goreleaser.git")
-	_, err := git.Run("pull", "upstream", "main")
+	_, err := git.Run(ctx, "pull", "upstream", "main")
 	require.NoError(t, err)
-	_, err = git.Run("branch", "--set-upstream-to", "upstream/main")
+	_, err = git.Run(ctx, "branch", "--set-upstream-to", "upstream/main")
 	require.NoError(t, err)
-	repo, err := git.ExtractRepoFromConfig()
+	repo, err := git.ExtractRepoFromConfig(ctx)
 	require.NoError(t, err)
 	require.Equal(t, "goreleaser/goreleaser", repo.String())
 }
