@@ -3,6 +3,7 @@
 package config
 
 import (
+	"encoding/json"
 	"io"
 	"os"
 	"strings"
@@ -11,8 +12,8 @@ import (
 	"github.com/alecthomas/jsonschema"
 
 	"github.com/apex/log"
+	"github.com/goreleaser/goreleaser/internal/yaml"
 	"github.com/goreleaser/nfpm/v2/files"
-	yaml "gopkg.in/yaml.v2"
 )
 
 // GitHubURLs holds the URLs to be used when using github enterprise.
@@ -128,6 +129,7 @@ type AUR struct {
 	GitURL                string       `yaml:"git_url,omitempty"`
 	GitSSHCommand         string       `yaml:"git_ssh_command,omitempty"`
 	PrivateKey            string       `yaml:"private_key,omitempty"`
+	Goamd64               string       `yaml:"goamd64,omitempty"`
 }
 
 // GoFish contains the gofish section.
@@ -143,7 +145,7 @@ type GoFish struct {
 	URLTemplate           string       `yaml:"url_template,omitempty"`
 	IDs                   []string     `yaml:"ids,omitempty"`
 	Goarm                 string       `yaml:"goarm,omitempty"`
-}
+} // deprecated
 
 // Homebrew contains the brew section.
 type Homebrew struct {
@@ -169,6 +171,7 @@ type Homebrew struct {
 	CustomBlock           string               `yaml:"custom_block,omitempty"`
 	IDs                   []string             `yaml:"ids,omitempty"`
 	Goarm                 string               `yaml:"goarm,omitempty"`
+	Goamd64               string               `yaml:"goamd64,omitempty"`
 	Service               string               `yaml:"service,omitempty"`
 }
 
@@ -185,6 +188,7 @@ type Krew struct {
 	Homepage              string       `yaml:"homepage,omitempty"`
 	URLTemplate           string       `yaml:"url_template,omitempty"`
 	Goarm                 string       `yaml:"goarm,omitempty"`
+	Goamd64               string       `yaml:"goamd64,omitempty"`
 	SkipUpload            string       `yaml:"skip_upload,omitempty"`
 }
 
@@ -203,6 +207,7 @@ type Scoop struct {
 	SkipUpload            string       `yaml:"skip_upload,omitempty"`
 	PreInstall            []string     `yaml:"pre_install,omitempty"`
 	PostInstall           []string     `yaml:"post_install,omitempty"`
+	Goamd64               string       `yaml:"goamd64,omitempty"`
 }
 
 // CommitAuthor is the author of a Git commit.
@@ -219,10 +224,11 @@ type BuildHooks struct { // renamed on pro
 
 // IgnoredBuild represents a build ignored by the user.
 type IgnoredBuild struct {
-	Goos   string `yaml:"goos,omitempty"`
-	Goarch string `yaml:"goarch,omitempty"`
-	Goarm  string `yaml:"goarm,omitempty"`
-	Gomips string `yaml:"gomips,omitempty"`
+	Goos    string `yaml:"goos,omitempty"`
+	Goarch  string `yaml:"goarch,omitempty"`
+	Goarm   string `yaml:"goarm,omitempty"`
+	Gomips  string `yaml:"gomips,omitempty"`
+	Goamd64 string `yaml:"goamd64,omitempty"`
 }
 
 // StringArray is a wrapper for an array of strings.
@@ -294,6 +300,7 @@ type Build struct {
 	Goarch          []string        `yaml:"goarch,omitempty"`
 	Goarm           []string        `yaml:"goarm,omitempty"`
 	Gomips          []string        `yaml:"gomips,omitempty"`
+	Goamd64         []string        `yaml:"goamd64,omitempty"`
 	Targets         []string        `yaml:"targets,omitempty"`
 	Ignore          []IgnoredBuild  `yaml:"ignore,omitempty"`
 	Dir             string          `yaml:"dir,omitempty"`
@@ -318,6 +325,7 @@ type BuildDetailsOverride struct {
 	Goarch       string           `yaml:"goarch,omitempty"`
 	Goarm        string           `yaml:"goarm,omitempty"`
 	Gomips       string           `yaml:"gomips,omitempty"`
+	Goamd64      string           `yaml:"goamd64,omitempty"`
 	BuildDetails `yaml:",inline"` // nolint: tagliatelle
 }
 
@@ -781,6 +789,7 @@ type Docker struct {
 	Goos               string   `yaml:"goos,omitempty"`
 	Goarch             string   `yaml:"goarch,omitempty"`
 	Goarm              string   `yaml:"goarm,omitempty"`
+	Goamd64            string   `yaml:"goamd64,omitempty"`
 	Dockerfile         string   `yaml:"dockerfile,omitempty"`
 	ImageTemplates     []string `yaml:"image_templates,omitempty"`
 	SkipPush           string   `yaml:"skip_push,omitempty"`
@@ -892,7 +901,7 @@ type Project struct {
 	Release         Release          `yaml:"release,omitempty"`
 	Milestones      []Milestone      `yaml:"milestones,omitempty"`
 	Brews           []Homebrew       `yaml:"brews,omitempty"`
-	Rigs            []GoFish         `yaml:"rigs,omitempty"`
+	Rigs            []GoFish         `yaml:"rigs,omitempty"` // deprecated
 	AURs            []AUR            `yaml:"aurs,omitempty"`
 	Krews           []Krew           `yaml:"krews,omitempty"`
 	Scoop           Scoop            `yaml:"scoop,omitempty"`
@@ -979,12 +988,14 @@ type Reddit struct {
 }
 
 type Slack struct {
-	Enabled         bool   `yaml:"enabled,omitempty"`
-	MessageTemplate string `yaml:"message_template,omitempty"`
-	Channel         string `yaml:"channel,omitempty"`
-	Username        string `yaml:"username,omitempty"`
-	IconEmoji       string `yaml:"icon_emoji,omitempty"`
-	IconURL         string `yaml:"icon_url,omitempty"`
+	Enabled         bool              `yaml:"enabled,omitempty"`
+	MessageTemplate string            `yaml:"message_template,omitempty"`
+	Channel         string            `yaml:"channel,omitempty"`
+	Username        string            `yaml:"username,omitempty"`
+	IconEmoji       string            `yaml:"icon_emoji,omitempty"`
+	IconURL         string            `yaml:"icon_url,omitempty"`
+	Blocks          []SlackBlock      `yaml:"blocks,omitempty"`
+	Attachments     []SlackAttachment `yaml:"attachments,omitempty"`
 }
 
 type Discord struct {
@@ -1058,3 +1069,47 @@ func LoadReader(fd io.Reader) (config Project, err error) {
 	log.WithField("config", config).Debug("loaded config file")
 	return config, err
 }
+
+// SlackBlock represents the untyped structure of a rich slack message layout.
+type SlackBlock struct {
+	Internal interface{}
+}
+
+// UnmarshalYAML is a custom unmarshaler that unmarshals a YAML slack block as untyped interface{}.
+func (a *SlackBlock) UnmarshalYAML(unmarshal func(interface{}) error) error {
+	var yamlv2 interface{}
+	if err := unmarshal(&yamlv2); err != nil {
+		return err
+	}
+
+	a.Internal = yamlv2
+
+	return nil
+}
+
+// MarshalJSON marshals a slack block as JSON.
+func (a SlackBlock) MarshalJSON() ([]byte, error) {
+	return json.Marshal(a.Internal)
+}
+
+// SlackAttachment represents the untyped structure of a slack message attachment.
+type SlackAttachment struct {
+	Internal interface{}
+}
+
+// UnmarshalYAML is a custom unmarshaler that unmarshals a YAML slack attachment as untyped interface{}.
+func (a *SlackAttachment) UnmarshalYAML(unmarshal func(interface{}) error) error {
+	var yamlv2 interface{}
+	if err := unmarshal(&yamlv2); err != nil {
+		return err
+	}
+
+	a.Internal = yamlv2
+
+	return nil
+}
+
+// MarshalJSON marshals a slack attachment as JSON.
+func (a SlackAttachment) MarshalJSON() ([]byte, error) {
+	return json.Marshal(a.Internal)
+}
